@@ -15,7 +15,7 @@ use Types::Standard -types;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 
 has resolver => (
@@ -43,10 +43,12 @@ has robots => (
 
 sub _build_robots {
     return [
+
         {
-            name   => 'Google',
-            agent  => qr/\bGoogle(?:bot?)\b/i,
-            domain => qr/\.google(?:bot)?\.com$/,
+            name   => 'Baidu',
+            agent  => qr/\bBaiduspider\b/,
+            domain => qr/\.crawl\.baidu\.com$/,
+
         },
 
         {
@@ -57,10 +59,45 @@ sub _build_robots {
         },
 
         {
-            name   => 'Baidu',
-            agent  => qr/\bBaiduspider\b/,
-            domain => qr/\.crawl\.baidu\.com$/,
+            name   => 'Embedly',
+            agent  => qr/\bEmbedly\b/,
+            domain => qr/\.embed\.ly$/,
+        },
 
+        {
+            name   => 'Exabot',
+            agent  => qr/\bExabot\b/i,
+            domain => qr/\.exabot\.com$/,
+        },
+
+        {
+            name   => 'Google',
+            agent  => qr/\bGoogle(?:bot?)\b/i,
+            domain => qr/\.google(?:bot)?\.com$/,
+        },
+
+        {
+            name   => 'LinkedIn',
+            agent  => qr/\bLinkedInBot\b/,
+            domain => qr/\.linkedin\.com$/,
+        },
+
+        {
+            name   => 'Mojeek',
+            agent  => qr/\bMojeekBot\b/,
+            domain => qr/\.mojeek\.com$/,
+        },
+
+        {
+            name   => 'Pinterest',
+            agent  => qr/\bPinterest\b/,
+            domain => qr/\.pinterest\.com$/,
+        },
+
+        {
+            name   => 'Sogou',
+            agent  => qr/\bSogou\b/,
+            domain => qr/\.sogou\.com$/,
         },
 
         {
@@ -75,6 +112,13 @@ sub _build_robots {
             agent  => qr/Yandex/,
             domain => qr/\.yandex\.(?:com|ru|net)$/,
         },
+
+        {
+            name   => 'Yeti',
+            agent  => qr/\bnaver\.me\b/,
+            domain => qr/\.naver\.com$/,
+        },
+
     ];
 }
 
@@ -113,7 +157,7 @@ sub validate {
       grep { !$agent || $agent =~ $_->{agent} } @{ $self->robots };
 
     my $reply = $res->search( $hostname, "A" )
-        or $self->die_on_error && die $res->errorstring;
+      or $self->die_on_error && die $res->errorstring;
 
     return unless $reply;
 
@@ -122,12 +166,11 @@ sub validate {
             map  { $_->address }
             grep { $_->can('address') } $reply->answer
         )
-        )
+      )
     {
         return;
     }
 
-
     if ( my $match = first { $hostname =~ $_->{domain} } @matches ) {
 
         return {
@@ -156,7 +199,7 @@ Robots::Validate - validate IP addresses are associated with known robots
 
 =head1 VERSION
 
-version v0.1.1
+version v0.1.2
 
 =head1 SYNOPSIS
 
@@ -231,13 +274,23 @@ It is optional.
 
 =back
 
+=head1 KNOWN ISSUES
+
+=head2 Limitations
+
+The current module can only be used for systems that consistently
+support reverse DNS lookups. This means that it cannot be used to
+validate some robots from
+L<Facebook|https://developers.facebook.com/docs/sharing/webmasters/crawler>
+or Twitter.
+
 =head1 SEE ALSO
 
 =over
 
 =item L<Verifying Bingbot|https://www.bing.com/webmaster/help/how-to-verify-bingbot-3905dc26>
 
-=item L<Verifying Goodlebot|https://support.google.com/webmasters/answer/80553>
+=item L<Verifying Googlebot|https://support.google.com/webmasters/answer/80553>
 
 =item L<How to check that a robot belongs to Yandex|https://yandex.com/support/webmaster/robot-workings/check-yandex-robots.html>
 
